@@ -7,6 +7,7 @@ void init(void)
 	initscr();
 	init_kb();
 	srand((unsigned) time ( NULL ));
+	world_pad = newpad(world_row, world_col);
 	clear();
 	start();
 }
@@ -19,7 +20,7 @@ void start(void)
 	// place blocks ..
 	attron(A_DIM);
 	for(loop = 1; loop <= NUM_BLOCKS; loop++)
-		mvprintw(getrandom(0,LINES-2),getrandom(0,COLS-1),"%c",BLOCK);
+		mvwprintw(world_pad, getrandom(0,world_row-1),getrandom(0,world_col-1),"%c",BLOCK);
 	attroff(A_DIM);
 	
 	// place food
@@ -32,8 +33,8 @@ void start(void)
 	{
 		population++;
 		temp = (struct bug *) malloc (sizeof(struct bug));
-		temp->xpos = getrandom(0,COLS-1);
-		temp->ypos = getrandom(0,LINES-2);
+		temp->xpos = getrandom(0,world_col-1);
+		temp->ypos = getrandom(0,world_row-1);
 		temp->vector = getrandom(0,3);
 		temp->food = INIT_FOOD;
 		temp->food_type = FOOD3;
@@ -58,6 +59,7 @@ void start(void)
 
 void stop(void)
 {
+	delwin(world_pad);
 	close_kb();
 	endwin();
 	exit(0);
